Exception: Splunk::IllegalOperation
- Inherits:
-
StandardError
- Object
- StandardError
- Splunk::IllegalOperation
- Defined in:
- lib/splunk-sdk-ruby/illegal_operation.rb
Overview
Exception thrown when a call is known statically to fail.
IllegalOperation is meant to be thrown when a call can be statically
inferred to fail, such as trying to delete an index on versions of Splunk
before 5.0. It implies that no round trips to the server were made.