Class: String
- Inherits:
-
Object
- Object
- String
- Defined in:
- lib/splunk-sdk-ruby/atomfeed.rb
Overview
– Nokogiri returns attribute values as objects on which we have to call #text. REXML returns Strings. To make them both work, add a text method to String that returns itself. ++
Instance Method Summary collapse
-
#text ⇒ Object
:nodoc:.
Instance Method Details
#text ⇒ Object
:nodoc:
30 31 32 |
# File 'lib/splunk-sdk-ruby/atomfeed.rb', line 30 def text self end |